# Easy QL

EasyQL is a SQLFluff plugin

## Installation

Before the plugin is released as a PyPi package, to use it locally you can download the code in the repo and run the following command from the main directory:

```sh
pip install -e .
```
